summaryrefslogtreecommitdiffstats
path: root/src/gui/general/ProgressReporter.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/general/ProgressReporter.h')
-rw-r--r--src/gui/general/ProgressReporter.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/src/gui/general/ProgressReporter.h b/src/gui/general/ProgressReporter.h
index 3e87ba0..7039e92 100644
--- a/src/gui/general/ProgressReporter.h
+++ b/src/gui/general/ProgressReporter.h
@@ -36,24 +36,25 @@ namespace Rosegarden
-class ProgressReporter : public QObject
+class ProgressReporter : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
- ProgressReporter(TQObject* parent, const char* name = 0);
+ ProgressReporter(TQObject* tqparent, const char* name = 0);
// exception class for cancellations
class Cancelled { };
protected:
/**
* Call this at appropriate times if you know Qt isn't in the stack
*/
void throwIfCancelled();
/*
We have to use these accessors rather than throwing directly
- from slotCancel() because Qt is generally compiled without
+ from slotCancel() because TQt is generally compiled without
exception support, so we can't throw from a slot.
*/
bool isOperationCancelled() const { return m_isCancelled; }
@@ -36,24 +36,25 @@ namespace Rosegarden
protected:
/**
- * Call this at appropriate times if you know Qt isn't in the stack
+ * Call this at appropriate times if you know TQt isn't in the stack
*/
void throwIfCancelled();